##  Step 3: Activate Notifications
After you configure the security settings, activate email notifications in your Exchange Online mailbox.
  1. SAP LeanIX, go to Administration > Notifications Center.
  2. For Email, choose Edit Settings, then go to the Custom Configuration tab.
  3. For Exchange Online, turn on the activation toggle.
